@@ -47,7 +47,7 @@ def img_cr(ctx, arg1, **kwargs):
                     label = int(re.sub(r'\D', '', a))
                 except ValueError:
                     label = i
-                print(label, r[0], r[1])
+                print(label, *r)
         except click.Abort:
             raise
         except Exception as ex:
@@ -155,6 +155,7 @@ def kde(ctx, arg1, **kwargs):
 @click.option('-resample', callback=clk.split_float)
 @click.option('--dototal/--no-dototal', default=False)
 @click.option('--legacy/--no-legacy', default=False)
+@click.option('--relative/--absolute', default=True)
 @click.option('-rng', default=None, callback=clk.split_int)
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def kde_error(ctx, arg1, arg2, outpref, **kwargs):
@@ -173,25 +174,22 @@ def kde_error(ctx, arg1, arg2, outpref, **kwargs):
         else:
             scale = 1
             select = None
-        b = a
-        if np.max(b) > 30:
-            baseline = np.log10(b)
-        else:
-            print('NO LOG CORRECTION')
-            baseline = b
-        return baseline, scale, select
+        return a, scale, select
 
 
-    def get_rdif(aS, a2S, i, select=None):
+    def get_rdif(aS, a2S, i, select=None, relative=True):
         if i < aS.shape[-1]:
             a = np.stack((aS[:,i],a2S[:,i])).T
         else:
             a = np.stack((aS.flatten(),a2S.flatten())).T
         la = len(a)
         if select is not None:
-            scale = la/maxN
+            a = a[select]
         b = a
-        return b[:,1]/b[:,0] - 1
+        if relative:
+            return b[:,1]/b[:,0] - 1
+        else:
+            return b[:,1] - b[:,0]
     
     if kwargs['opts']:
         kwargs['opts'] = False
@@ -212,7 +210,7 @@ def kde_error(ctx, arg1, arg2, outpref, **kwargs):
             for i in srng:
                 if kwargs['baselinei'] is None:
                     baseline, scale, select = get_baseline(aS, i)
-                rdif = get_rdif(aS, a2S, i, select)
+                rdif = get_rdif(aS, a2S, i, select, kwargs['relative'])
                 adif = np.abs(rdif)
                 out = hs.error_cont(baseline, adif, rdif, scale=scale,
                                   resample=kwargs['resample'])
